==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appflow/kotlin/inputs/FlowSourceFlowConfigSourceConnectorPropertiesSapoDataArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appflow.kotlin.inputs

import com.pulumi.aws.appflow.inputs.FlowSourceFlowConfigSourceConnectorPropertiesSapoDataArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property objectPath Object path specified in the SAPOData flow destination.
 */
public data class FlowSourceFlowConfigSourceConnectorPropertiesSapoDataArgs(
    public val objectPath: Output<String>,
) :
    ConvertibleToJava<com.pulumi.aws.appflow.inputs.FlowSourceFlowConfigSourceConnectorPropertiesSapoDataArgs> {
    override fun toJava():
        com.pulumi.aws.appflow.inputs.FlowSourceFlowConfigSourceConnectorPropertiesSapoDataArgs =
        com.pulumi.aws.appflow.inputs.FlowSourceFlowConfigSourceConnectorPropertiesSapoDataArgs.builder()
            .objectPath(objectPath.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [FlowSourceFlowConfigSourceConnectorPropertiesSapoDataArgs].
 */
@PulumiTagMarker
public class FlowSourceFlowConfigSourceConnectorPropertiesSapoDataArgsBuilder internal constructor() {
    private var objectPath: Output<String>? = null

    /**
     * @param value Object path specified in the SAPOData flow destination.
     */
    @JvmName("fmnrwvsotqeyxgnq")
    public suspend fun objectPath(`value`: Output<String>) {
        this.objectPath = value
    }

    /**
     * @param value Object path specified in the SAPOData flow destination.
     */
    @JvmName("ybavjqldxfqvtrru")
    public suspend fun objectPath(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.objectPath = mapped
    }

    internal fun build(): FlowSourceFlowConfigSourceConnectorPropertiesSapoDataArgs =
        FlowSourceFlowConfigSourceConnectorPropertiesSapoDataArgs(
            objectPath = objectPath ?: throw PulumiNullFieldException("objectPath"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appflow/kotlin/inputs/FlowSourceFlowConfigSourceConnectorPropertiesSapoDataArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appflow.kotlin.inputs

import com.pulumi.aws.appflow.inputs.FlowSourceFlowConfigSourceConnectorPropertiesSapoDataArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property objectPath
 */
public data class FlowSourceFlowConfigSourceConnectorPropertiesSapoDataArgs(
    public val objectPath: Output<String>,
) :
    ConvertibleToJava<com.pulumi.aws.appflow.inputs.FlowSourceFlowConfigSourceConnectorPropertiesSapoDataArgs> {
    override fun toJava(): com.pulumi.aws.appflow.inputs.FlowSourceFlowConfigSourceConnectorPropertiesSapoDataArgs =
        com.pulumi.aws.appflow.inputs.FlowSourceFlowConfigSourceConnectorPropertiesSapoDataArgs.builder()
            .objectPath(objectPath.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [FlowSourceFlowConfigSourceConnectorPropertiesSapoDataArgs].
 */
@PulumiTagMarker
public class FlowSourceFlowConfigSourceConnectorPropertiesSapoDataArgsBuilder internal constructor() {
    private var objectPath: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("qnidrsgyarpglhet")
    public suspend fun objectPath(`value`: Output<String>) {
        this.objectPath = value
    }

    /**
     * @param value
     */
    @JvmName("eymjtigvrgykvlhu")
    public suspend fun objectPath(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.objectPath = mapped
    }

    internal fun build(): FlowSourceFlowConfigSourceConnectorPropertiesSapoDataArgs =
        FlowSourceFlowConfigSourceConnectorPropertiesSapoDataArgs(
            objectPath = objectPath ?: throw PulumiNullFieldException("objectPath"),
        )
}
